Stan Math Library: stan/math/prim/mat/err/check_cholesky_factor_corr.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
check_cholesky_factor_corr.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/scal/err/check_positive.hpp>`
`#include <stan/math/prim/mat/err/check_lower_triangular.hpp>`
`#include <stan/math/prim/mat/err/check_square.hpp>`
`#include <stan/math/prim/mat/err/constraint_tolerance.hpp>`
`#include <stan/math/prim/mat/err/check_unit_vector.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T_y >
bool | stan::math::check_cholesky_factor_corr (const char *function, const char *name, const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y)
| Return `true` if the specified matrix is a valid Cholesky factor of a correlation matrix. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.